@@ -235,7 +235,7 @@ void video_output_qt_widget::focusOutEvent(QFocusEvent *)
 
 video_container_widget::video_container_widget(QWidget *parent) : QWidget(parent), _w(64), _h(64)
 {
-    setWindowIcon(QIcon(":logo/bino_logo_small_64x64.png"));
+    setWindowIcon(QIcon(":logo/bino/64x64/bino.png"));
     // Set minimum size > 0 so that the container is always visible
     setMinimumSize(_w, _h);
     // Set suitable size policy
@@ -393,6 +393,13 @@ void video_output_qt::deinit()
 void video_output_qt::create_widget()
 {
     _widget = new video_output_qt_widget(this, _format, _container_widget);
+    if (!_widget->context()->isValid())
+    {
+        // TODO: replace the error message with a better one once the freeze
+        // of translatable strings is over.
+        QMessageBox::critical(_widget, _("Error"), _("Cannot set OpenGL context format."));
+        std::exit(1);
+    }
     QObject::connect(_container_widget, SIGNAL(move_event()), _widget, SLOT(move_event()));
     if ((_format.doubleBuffer() && !_widget->format().doubleBuffer())
             || (_format.stereo() && !_widget->format().stereo()))
@@ -413,7 +420,7 @@ void video_output_qt::create_widget()
         catch (std::exception &e)
         {
             QMessageBox::critical(_widget, _("Error"), e.what());
-            abort();
+            std::exit(1);
         }
     }
     QGridLayout *container_layout = new QGridLayout();
@@ -671,6 +678,8 @@ void video_output_qt::enter_fullscreen(int screens)
             /* According to the Qt documentation, it should be sufficient to call activateWindow()
              * to make a X11 window active when using Qt::X11BypassWindowManagerHint, but this
              * does not work for me (Ubuntu 11.04 Gnome-2D desktop). This is a workaround. */
+            /* Note that using X11 functions directly means that we have to link with libX11
+             * explicitly; see configure.ac. */
             QApplication::syncX();      // just for safety; not sure if it is necessary
             XSetInputFocus(QX11Info::display(), _container_widget->winId(), RevertToParent, CurrentTime);
             XFlush(QX11Info::display());
